@@ -11,7 +11,7 @@ def create_bot(user_key,username,host,botname):
         output = botname + ' has been created!'
     else:
         output = 'Bot creation failed! ' + response.json()['message'] + '.'
-    print output
+    return output
 
 def delete_bot(user_key,username,host,botname):
     path = '/bot/' + username +'/' + botname
@@ -24,7 +24,7 @@ def delete_bot(user_key,username,host,botname):
     else: 
         output = 'No bot named ' + botname + ' was found. '
         output += '%d %s' % (response.status_code, response.reason)
-    print output
+    return output
 
 def upload_file(user_key,username,host,botname,filename,file_kind):
     path = '/bot/' + username + '/' + botname + '/'
@@ -39,9 +39,9 @@ def upload_file(user_key,username,host,botname,filename,file_kind):
     query = {"user_key": user_key}
     response = requests.put(url, params=query, data=data)
     if response.ok:
-        print filename + ' successfully uploaded'
+        return filename + ' successfully uploaded'
     else:
-        print response.reason
+        return response.reason
 
 def compile_bot(user_key,username,host, botname):
     path = '/bot/' + username +'/' + botname + '/verify'
@@ -55,9 +55,9 @@ def compile_bot(user_key,username,host, botname):
         message = result["message"]
         error = str(result["errors"][0])
         output = message + '\n' + error + '\n'
-    print output
+    return output
 
-def talk(user_key, username, host, botname, input_text, session_id, recent=False, reset=False, trace=False, clientID=False):
+def talk(user_key, username, host, botname, input_text, session_id=False, recent=False, reset=False, trace=False, clientID=False):
     path = '/talk/' + username + '/' + botname
     url = host_base + host + path
     query = {"user_key": user_key,
@@ -77,32 +77,31 @@ def talk(user_key, username, host, botname, input_text, session_id, recent=False
     result = response.json()
     status = result['status']
     if status == 'ok':
-        output = result['responses'][0] + '\n'
+        output = {"response": result['responses'][0]}
         if reset:
-            output += 'Bot has been reset.\n'
+            output["output"] = 'Bot has been reset.'
         if trace:
             trace_text = result['trace']
-            output += 'Trace: \n'
+            trace_string = 'Trace: '
             length = range(len(trace_text))
             every_other = length[::2][:-1]
             for elt in every_other:
-                output+='Level: ' + str(trace_text[elt]['level']) 
-                output += ' Sentence to process: ' 
+                trace_string +='Level: ' + str(trace_text[elt]['level']) 
+                trace_string += ' Sentence to process: ' 
                 for elt1 in range(len(trace_text[elt]['input'])):
-                    output += str(trace_text[elt]['input'][elt1]) + ' '
-                output += '\nMatched pattern: ' + str(trace_text[elt+1]['matched'][0])
-                output += ' from file: ' + trace_text[elt+1]['filename'] + '\n'
-                output += 'template: ' + trace_text[elt+1]['template'] + '\n\n'
+                    trace_string += str(trace_text[elt]['input'][elt1]) + ' '
+                trace_string += 'Matched pattern: ' + str(trace_text[elt+1]['matched'][0])
+                trace_string += ' from file: ' + trace_text[elt+1]['filename']
+                trace_string += 'template: ' + trace_text[elt+1]['template']
+            output["trace"] = trace_string
         if 'sessionid'  in result:
-            sessionid = result['sessionid']
+            output["sessionid"] = result['sessionid']
     else:
-        output = result['message']
-        sessionid = ''
-    print output
-    return sessionid
+        output["response"] = result['message']
+    return output
 
 
 def debug_bot(user_key, username, host, botname, input_text, session_id='', recent=False, reset=False, trace=False):
-    talk(user_key, username, host, botname, input_text, session_id, recent, reset, trace)
-
+    response = talk(user_key, username, host, botname, input_text, session_id, recent, reset, trace)
+    return response
                           
