@@ -8,7 +8,9 @@ API.create_bot(user_key, username, host,'test')
 
 API.upload_file(user_key, username, host,'test','test.aiml','aiml')
 API.compile_bot(user_key, username, host, 'test')
-session_id = API.init_talk(user_key,username, host, 'test','hello')
-API.talk(user_key,username, host, 'test','how are you',session_id)
-API.debug_bot(user_key,username,host, 'test','hello', recent= True, trace = True)
+
+x = API.talk(user_key,username, host, 'test','how are you')
+print x
+y = API.debug_bot(user_key,username,host, 'test','hello', recent= True, trace = True)
+print y
 API.delete_bot(user_key,username, host, 'test')
